@@ -15,7 +15,7 @@
 
 import logging
 
-import pkg_resources
+import stevedore
 
 from . import utils
 
@@ -50,11 +50,10 @@ class EntryPointWrapper(object):
 class CommandManager(object):
     """Discovers commands and handles lookup based on argv data.
 
-    :param namespace: String containing the setuptools entrypoint namespace
-                      for the plugins to be loaded. For example,
-                      ``'cliff.formatter.list'``.
+    :param namespace: String containing the entrypoint namespace for the
+        plugins to be loaded. For example, ``'cliff.formatter.list'``.
     :param convert_underscores: Whether cliff should convert underscores to
-                                spaces in entry_point commands.
+        spaces in entry_point commands.
     """
     def __init__(self, namespace, convert_underscores=True):
         self.commands = {}
@@ -72,12 +71,12 @@ class CommandManager(object):
     def load_commands(self, namespace):
         """Load all the commands from an entrypoint"""
         self.group_list.append(namespace)
-        for ep in pkg_resources.iter_entry_points(namespace):
+        for ep in stevedore.ExtensionManager(namespace):
             LOG.debug('found command %r', ep.name)
             cmd_name = (ep.name.replace('_', ' ')
                         if self.convert_underscores
                         else ep.name)
-            self.commands[cmd_name] = ep
+            self.commands[cmd_name] = ep.entry_point
         return
 
     def __iter__(self):
@@ -93,7 +92,6 @@ class CommandManager(object):
         :type old_name: str
         :param new_name: The new command name.
         :type new_name: str
-
         """
         self._legacy[old_name] = new_name
 
@@ -159,7 +157,7 @@ class CommandManager(object):
         """Returns a list of commands loaded for the specified group"""
         group_list = []
         if group is not None:
-            for ep in pkg_resources.iter_entry_points(group):
+            for ep in stevedore.ExtensionManager(group):
                 cmd_name = (
                     ep.name.replace('_', ' ')
                     if self.convert_underscores
