@@ -13,8 +13,6 @@
 """Output formatters values only
 """
 
-import six
-
 from . import base
 from cliff import columns
 
@@ -28,15 +26,15 @@ class ValueFormatter(base.ListFormatter, base.SingleFormatter):
         for row in data:
             stdout.write(
                 ' '.join(
-                    six.text_type(c.machine_readable()
-                                  if isinstance(c, columns.FormattableColumn)
-                                  else c)
+                    str(c.machine_readable()
+                        if isinstance(c, columns.FormattableColumn)
+                        else c)
                     for c in row) + u'\n')
         return
 
     def emit_one(self, column_names, data, stdout, parsed_args):
         for value in data:
-            stdout.write('%s\n' % six.text_type(
+            stdout.write('%s\n' % str(
                 value.machine_readable()
                 if isinstance(value, columns.FormattableColumn)
                 else value)
