@@ -12,13 +12,24 @@
 
 import argparse
 import inspect
-import sys
 import traceback
 
 from . import command
+from . import utils
+
+
+class HelpExit(SystemExit):
+    """Special exception type to trigger quick exit from the application
+
+    We subclass from SystemExit to preserve API compatibility for
+    anything that used to catch SystemExit, but use a different class
+    so that cliff's Application can tell the difference between
+    something trying to hard-exit and help saying it's done.
+    """
 
 
 class HelpAction(argparse.Action):
+
     """Provide a custom action so the -h and --help options
     to the main app will print a list of the commands.
 
@@ -29,6 +40,13 @@ class HelpAction(argparse.Action):
         app = self.default
         parser.print_help(app.stdout)
         app.stdout.write('\nCommands:\n')
+        dists_by_module = command._get_distributions_by_modules()
+
+        def dist_for_obj(obj):
+            name = inspect.getmodule(obj).__name__.partition('.')[0]
+            return dists_by_module.get(name)
+
+        app_dist = dist_for_obj(app)
         command_manager = app.command_manager
         for name, ep in sorted(command_manager):
             try:
@@ -40,7 +58,7 @@ class HelpAction(argparse.Action):
                 continue
             try:
                 kwargs = {}
-                if 'cmd_name' in inspect.getargspec(factory.__init__).args:
+                if 'cmd_name' in utils.getargspec(factory.__init__).args:
                     kwargs['cmd_name'] = name
                 cmd = factory(app, None, **kwargs)
                 if cmd.deprecated:
@@ -51,8 +69,13 @@ class HelpAction(argparse.Action):
                     traceback.print_exc(file=app.stdout)
                 continue
             one_liner = cmd.get_description().split('\n')[0]
-            app.stdout.write('  %-13s  %s\n' % (name, one_liner))
-        sys.exit(0)
+            dist_name = dist_for_obj(factory)
+            if dist_name and dist_name != app_dist:
+                dist_info = ' (' + dist_name + ')'
+            else:
+                dist_info = ''
+            app.stdout.write('  %-13s  %s%s\n' % (name, one_liner, dist_info))
+        raise HelpExit()
 
 
 class HelpCommand(command.Command):
@@ -88,7 +111,7 @@ class HelpCommand(command.Command):
                 return
             self.app_args.cmd = search_args
             kwargs = {}
-            if 'cmd_name' in inspect.getargspec(cmd_factory.__init__).args:
+            if 'cmd_name' in utils.getargspec(cmd_factory.__init__).args:
                 kwargs['cmd_name'] = cmd_name
             cmd = cmd_factory(self.app, self.app_args, **kwargs)
             full_name = (cmd_name
